/****************************************************************************
** Meta object code from reading C++ file 'kmodifierkeyinfoprovider_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kguiaddons-6.27.0/src/util/kmodifierkeyinfoprovider_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmodifierkeyinfoprovider_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24KModifierKeyInfoProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto KModifierKeyInfoProvider::qt_create_metaobjectdata<qt_meta_tag_ZN24KModifierKeyInfoProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KModifierKeyInfoProvider",
        "keyLatched",
        "",
        "Qt::Key",
        "key",
        "state",
        "keyLocked",
        "keyPressed",
        "buttonPressed",
        "Qt::MouseButton",
        "button",
        "keyAdded",
        "keyRemoved",
        "ModifierState",
        "Nothing",
        "Pressed",
        "Latched",
        "Locked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'keyLatched'
        QtMocHelpers::SignalData<void(Qt::Key, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'keyLocked'
        QtMocHelpers::SignalData<void(Qt::Key, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'keyPressed'
        QtMocHelpers::SignalData<void(Qt::Key, bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'buttonPressed'
        QtMocHelpers::SignalData<void(Qt::MouseButton, bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'keyAdded'
        QtMocHelpers::SignalData<void(Qt::Key)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'keyRemoved'
        QtMocHelpers::SignalData<void(Qt::Key)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ModifierState'
        QtMocHelpers::EnumData<enum ModifierState>(13, 13, QMC::EnumFlags{}).add({
            {   14, ModifierState::Nothing },
            {   15, ModifierState::Pressed },
            {   16, ModifierState::Latched },
            {   17, ModifierState::Locked },
        }),
    };
    return QtMocHelpers::metaObjectData<KModifierKeyInfoProvider, qt_meta_tag_ZN24KModifierKeyInfoProviderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KModifierKeyInfoProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KModifierKeyInfoProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KModifierKeyInfoProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24KModifierKeyInfoProviderE_t>.metaTypes,
    nullptr
} };

void KModifierKeyInfoProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KModifierKeyInfoProvider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->keyLatched((*reinterpret_cast<std::add_pointer_t<Qt::Key>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->keyLocked((*reinterpret_cast<std::add_pointer_t<Qt::Key>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->keyPressed((*reinterpret_cast<std::add_pointer_t<Qt::Key>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->buttonPressed((*reinterpret_cast<std::add_pointer_t<Qt::MouseButton>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->keyAdded((*reinterpret_cast<std::add_pointer_t<Qt::Key>>(_a[1]))); break;
        case 5: _t->keyRemoved((*reinterpret_cast<std::add_pointer_t<Qt::Key>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KModifierKeyInfoProvider::*)(Qt::Key , bool )>(_a, &KModifierKeyInfoProvider::keyLatched, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KModifierKeyInfoProvider::*)(Qt::Key , bool )>(_a, &KModifierKeyInfoProvider::keyLocked, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KModifierKeyInfoProvider::*)(Qt::Key , bool )>(_a, &KModifierKeyInfoProvider::keyPressed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KModifierKeyInfoProvider::*)(Qt::MouseButton , bool )>(_a, &KModifierKeyInfoProvider::buttonPressed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KModifierKeyInfoProvider::*)(Qt::Key )>(_a, &KModifierKeyInfoProvider::keyAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KModifierKeyInfoProvider::*)(Qt::Key )>(_a, &KModifierKeyInfoProvider::keyRemoved, 5))
            return;
    }
}

const QMetaObject *KModifierKeyInfoProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KModifierKeyInfoProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KModifierKeyInfoProviderE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QSharedData"))
        return static_cast< QSharedData*>(this);
    return QObject::qt_metacast(_clname);
}

int KModifierKeyInfoProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KModifierKeyInfoProvider::keyLatched(Qt::Key _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KModifierKeyInfoProvider::keyLocked(Qt::Key _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KModifierKeyInfoProvider::keyPressed(Qt::Key _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KModifierKeyInfoProvider::buttonPressed(Qt::MouseButton _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void KModifierKeyInfoProvider::keyAdded(Qt::Key _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KModifierKeyInfoProvider::keyRemoved(Qt::Key _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
