/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<systeminhibitor.h>)
#  include <systeminhibitor.h>
#endif
#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_guiaddons()
{
    qmlRegisterModule("org.kde.guiaddons", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<KSystemInhibitor *>().id();
    qmlRegisterEnum<KSystemInhibitor::Type>("KSystemInhibitor::Type");
    qmlRegisterEnum<KSystemInhibitor::Types>("KSystemInhibitor::Types");
    qmlRegisterEnum<KSystemInhibitor::Type>("KSystemInhibitor::Type");
    qmlRegisterTypesAndRevisions<KWindowInsetsControllerForeign>("org.kde.guiaddons", 254);
    qmlRegisterTypesAndRevisions<SystemInhibitor>("org.kde.guiaddons", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.guiaddons", 254, 254);
}

static const QQmlModuleRegistration orgkdeguiaddonsRegistration("org.kde.guiaddons", qml_register_types_org_kde_guiaddons);
