// This file was generated by qtwaylandscanner
// source file is keyboard-shortcuts-inhibit-unstable-v1.xml

#ifndef QT_WAYLAND_KEYBOARD_SHORTCUTS_INHIBIT_UNSTABLE_V1
#define QT_WAYLAND_KEYBOARD_SHORTCUTS_INHIBIT_UNSTABLE_V1

#include "wayland-keyboard-shortcuts-inhibit-unstable-v1-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  zwp_keyboard_shortcuts_inhibit_manager_v1
    {
    public:
        zwp_keyboard_shortcuts_inhibit_manager_v1(struct ::wl_registry *registry, uint32_t id, int version);
        zwp_keyboard_shortcuts_inhibit_manager_v1(struct ::zwp_keyboard_shortcuts_inhibit_manager_v1 *object);
        zwp_keyboard_shortcuts_inhibit_manager_v1();

        virtual ~zwp_keyboard_shortcuts_inhibit_manager_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::zwp_keyboard_shortcuts_inhibit_manager_v1 *object);

        struct ::zwp_keyboard_shortcuts_inhibit_manager_v1 *object() { return m_zwp_keyboard_shortcuts_inhibit_manager_v1; }
        const struct ::zwp_keyboard_shortcuts_inhibit_manager_v1 *object() const { return m_zwp_keyboard_shortcuts_inhibit_manager_v1; }
        static zwp_keyboard_shortcuts_inhibit_manager_v1 *fromObject(struct ::zwp_keyboard_shortcuts_inhibit_manager_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum error {
            error_already_inhibited = 0, // the shortcuts are already inhibited for this surface
        };

        void destroy();
        struct ::zwp_keyboard_shortcuts_inhibitor_v1 *inhibit_shortcuts(struct ::wl_surface *surface, struct ::wl_seat *seat);

    private:
        struct ::zwp_keyboard_shortcuts_inhibit_manager_v1 *m_zwp_keyboard_shortcuts_inhibit_manager_v1;
    };

    class  zwp_keyboard_shortcuts_inhibitor_v1
    {
    public:
        zwp_keyboard_shortcuts_inhibitor_v1(struct ::wl_registry *registry, uint32_t id, int version);
        zwp_keyboard_shortcuts_inhibitor_v1(struct ::zwp_keyboard_shortcuts_inhibitor_v1 *object);
        zwp_keyboard_shortcuts_inhibitor_v1();

        virtual ~zwp_keyboard_shortcuts_inhibitor_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::zwp_keyboard_shortcuts_inhibitor_v1 *object);

        struct ::zwp_keyboard_shortcuts_inhibitor_v1 *object() { return m_zwp_keyboard_shortcuts_inhibitor_v1; }
        const struct ::zwp_keyboard_shortcuts_inhibitor_v1 *object() const { return m_zwp_keyboard_shortcuts_inhibitor_v1; }
        static zwp_keyboard_shortcuts_inhibitor_v1 *fromObject(struct ::zwp_keyboard_shortcuts_inhibitor_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void destroy();

    protected:
        virtual void zwp_keyboard_shortcuts_inhibitor_v1_active();
        virtual void zwp_keyboard_shortcuts_inhibitor_v1_inactive();

    private:
        void init_listener();
        static const struct zwp_keyboard_shortcuts_inhibitor_v1_listener m_zwp_keyboard_shortcuts_inhibitor_v1_listener;
        static void handle_active(
            void *data,
            struct ::zwp_keyboard_shortcuts_inhibitor_v1 *object);
        static void handle_inactive(
            void *data,
            struct ::zwp_keyboard_shortcuts_inhibitor_v1 *object);
        struct ::zwp_keyboard_shortcuts_inhibitor_v1 *m_zwp_keyboard_shortcuts_inhibitor_v1;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
