

#ifndef SBK_KGUIADDONS_PYTHON_H
#define SBK_KGUIADDONS_PYTHON_H

//workaround to access protected functions
#define protected public

#include <sbkpython.h>
#include <sbkmodule.h>
#include <sbkconverter.h>
// Module Includes
#include <pyside6_qtcore_python.h>
#include <pyside6_qtgui_python.h>

// Bound library includes
#include <kcolormimedata.h>
#include <kcolorschemewatcher.h>
#include <kcolorutils.h>
#include <kcountryflagemojiiconengine.h>
#include <kcursorsaver.h>
#include <kdatevalidator.h>
#include <kfontutils.h>
#include <kiconutils.h>
#include <kjobwindows.h>
#include <kkeysequencerecorder.h>
#include <kmodifierkeyinfo.h>
#include <ksystemclipboard.h>
#include <kwordwrap.h>
// Conversion Includes - Primitive Types
#include <QAnyStringView>
#include <qbytearrayview.h>
#include <qchar.h>
#include <QtCore/qlatin1stringview.h>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <qvariant.h>

// Conversion Includes - Container Types
#include <QHash>
#include <QList>
#include <QMap>
#include <QMultiHash>
#include <QMultiMap>
#include <QPair>
#include <QQueue>
#include <QSet>
#include <QStack>
#include <array>
#include <list>
#include <map>
#include <utility>
#include <unordered_map>
#include <vector>


// Type indices
enum : int {
    SBK_KGuiAddonsKColorMimeData_IDX                         = 0,
    SBK_KColorSchemeWatcher_ColorPreference_IDX              = 2,
    SBK_KColorSchemeWatcher_IDX                              = 1,
    SBK_KGuiAddonsKColorUtils_IDX                            = 3,
    SBK_KCountryFlagEmojiIconEngine_IDX                      = 4,
    SBK_KCursorSaver_IDX                                     = 5,
    SBK_KDateValidator_IDX                                   = 6,
    SBK_KFontUtils_AdaptFontSizeOption_IDX                   = 8,
    SBK_QFlags_KFontUtils_AdaptFontSizeOption_IDX            = 16,
    SBK_KGuiAddonsKFontUtils_IDX                             = 7,
    SBK_KGuiAddonsKIconUtils_IDX                             = 9,
    SBK_KGuiAddonsKJobWindows_IDX                            = 10,
    SBK_KKeySequenceRecorder_Pattern_IDX                     = 12,
    SBK_QFlags_KKeySequenceRecorder_Pattern_IDX              = 17,
    SBK_KKeySequenceRecorder_IDX                             = 11,
    SBK_KModifierKeyInfo_IDX                                 = 13,
    SBK_KSystemClipboard_IDX                                 = 14,
    SBK_KWordWrap_IDX                                        = 15,
    SBK_KGuiAddons_IDX_COUNT                                 = 18,
};

// This variable stores all Python types exported by this module.
extern Shiboken::Module::TypeInitStruct *SbkKGuiAddonsTypeStructs;

// This variable stores the Python module object exported by this module.
extern PyObject *SbkKGuiAddonsModuleObject;

// This variable stores all type converters exported by this module.
extern SbkConverter **SbkKGuiAddonsTypeConverters;

// Converter indices
enum [[deprecated]] : int {
    SBK_KGUIADDONS_QLIST_INT_IDX                             = 0, // QList<int>
    SBK_KGUIADDONS_QLIST_QT_KEY_IDX                          = 1, // QList<Qt::Key>
    SBK_KGUIADDONS_QHASH_QT_CORNER_QICON_IDX                 = 2, // QHash<Qt::Corner,QIcon>
    SBK_KGUIADDONS_QLIST_QSIZE_IDX                           = 3, // QList<QSize>
    SBK_KGUIADDONS_QLIST_QVARIANT_IDX                        = 4, // QList<QVariant>
    SBK_KGUIADDONS_QLIST_QSTRING_IDX                         = 5, // QList<QString>
    SBK_KGUIADDONS_QMAP_QSTRING_QVARIANT_IDX                 = 6, // QMap<QString,QVariant>
    SBK_KGUIADDONS_CONVERTERS_IDX_COUNT                      = 7,
};

// Converter indices
enum : int {
    SBK_KGuiAddons_QList_int_IDX                             = 0, // QList<int>
    SBK_KGuiAddons_QList_Qt_Key_IDX                          = 1, // QList<Qt::Key>
    SBK_KGuiAddons_QHash_Qt_Corner_QIcon_IDX                 = 2, // QHash<Qt::Corner,QIcon>
    SBK_KGuiAddons_QList_QSize_IDX                           = 3, // QList<QSize>
    SBK_KGuiAddons_QList_QVariant_IDX                        = 4, // QList<QVariant>
    SBK_KGuiAddons_QList_QString_IDX                         = 5, // QList<QString>
    SBK_KGuiAddons_QMap_QString_QVariant_IDX                 = 6, // QMap<QString,QVariant>
    SBK_KGuiAddons_CONVERTERS_IDX_COUNT                      = 7,
};
// Macros for type check

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
template<> inline PyTypeObject *SbkType< ::KColorSchemeWatcher::ColorPreference >() { return Shiboken::Module::get(SbkKGuiAddonsTypeStructs[SBK_KColorSchemeWatcher_ColorPreference_IDX]); }
template<> inline PyTypeObject *SbkType< ::KColorSchemeWatcher >() { return Shiboken::Module::get(SbkKGuiAddonsTypeStructs[SBK_KColorSchemeWatcher_IDX]); }
template<> inline PyTypeObject *SbkType< ::KCountryFlagEmojiIconEngine >() { return Shiboken::Module::get(SbkKGuiAddonsTypeStructs[SBK_KCountryFlagEmojiIconEngine_IDX]); }
template<> inline PyTypeObject *SbkType< ::KCursorSaver >() { return Shiboken::Module::get(SbkKGuiAddonsTypeStructs[SBK_KCursorSaver_IDX]); }
template<> inline PyTypeObject *SbkType< ::KDateValidator >() { return Shiboken::Module::get(SbkKGuiAddonsTypeStructs[SBK_KDateValidator_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFontUtils::AdaptFontSizeOption >() { return Shiboken::Module::get(SbkKGuiAddonsTypeStructs[SBK_KFontUtils_AdaptFontSizeOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KFontUtils::AdaptFontSizeOption> >() { return Shiboken::Module::get(SbkKGuiAddonsTypeStructs[SBK_QFlags_KFontUtils_AdaptFontSizeOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::KKeySequenceRecorder::Pattern >() { return Shiboken::Module::get(SbkKGuiAddonsTypeStructs[SBK_KKeySequenceRecorder_Pattern_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KKeySequenceRecorder::Pattern> >() { return Shiboken::Module::get(SbkKGuiAddonsTypeStructs[SBK_QFlags_KKeySequenceRecorder_Pattern_IDX]); }
template<> inline PyTypeObject *SbkType< ::KKeySequenceRecorder >() { return Shiboken::Module::get(SbkKGuiAddonsTypeStructs[SBK_KKeySequenceRecorder_IDX]); }
template<> inline PyTypeObject *SbkType< ::KModifierKeyInfo >() { return Shiboken::Module::get(SbkKGuiAddonsTypeStructs[SBK_KModifierKeyInfo_IDX]); }
template<> inline PyTypeObject *SbkType< ::KSystemClipboard >() { return Shiboken::Module::get(SbkKGuiAddonsTypeStructs[SBK_KSystemClipboard_IDX]); }
template<> inline PyTypeObject *SbkType< ::KWordWrap >() { return Shiboken::Module::get(SbkKGuiAddonsTypeStructs[SBK_KWordWrap_IDX]); }

} // namespace Shiboken

QT_WARNING_POP
#endif // SBK_KGUIADDONS_PYTHON_H

