/****************************************************************************
** Meta object code from reading C++ file 'kcolorutilssingleton.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kguiaddons-6.27.0/src/qml/kcolorutilssingleton.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcolorutilssingleton.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20KColorUtilsSingletonE_t {};
} // unnamed namespace

template <> constexpr inline auto KColorUtilsSingleton::qt_create_metaobjectdata<qt_meta_tag_ZN20KColorUtilsSingletonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KColorUtilsSingleton",
        "hue",
        "",
        "QColor",
        "color",
        "chroma",
        "luma",
        "hcyColor",
        "alpha",
        "contrastRatio",
        "color1",
        "color2",
        "lighten",
        "amount",
        "chromaInverseGain",
        "darken",
        "chromaGain",
        "shade",
        "lumaAmount",
        "chromaAmount",
        "tint",
        "base",
        "mix",
        "bias"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'hue'
        QtMocHelpers::MethodData<qreal(const QColor &)>(1, 2, QMC::AccessPublic, QMetaType::QReal, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'chroma'
        QtMocHelpers::MethodData<qreal(const QColor &)>(5, 2, QMC::AccessPublic, QMetaType::QReal, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'luma'
        QtMocHelpers::MethodData<qreal(const QColor &)>(6, 2, QMC::AccessPublic, QMetaType::QReal, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'hcyColor'
        QtMocHelpers::MethodData<QColor(qreal, qreal, qreal, qreal)>(7, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::QReal, 1 }, { QMetaType::QReal, 5 }, { QMetaType::QReal, 6 }, { QMetaType::QReal, 8 },
        }}),
        // Method 'hcyColor'
        QtMocHelpers::MethodData<QColor(qreal, qreal, qreal)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { QMetaType::QReal, 1 }, { QMetaType::QReal, 5 }, { QMetaType::QReal, 6 },
        }}),
        // Method 'contrastRatio'
        QtMocHelpers::MethodData<qreal(const QColor &, const QColor &)>(9, 2, QMC::AccessPublic, QMetaType::QReal, {{
            { 0x80000000 | 3, 10 }, { 0x80000000 | 3, 11 },
        }}),
        // Method 'lighten'
        QtMocHelpers::MethodData<QColor(const QColor &, qreal, qreal)>(12, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QReal, 13 }, { QMetaType::QReal, 14 },
        }}),
        // Method 'lighten'
        QtMocHelpers::MethodData<QColor(const QColor &, qreal)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QReal, 13 },
        }}),
        // Method 'lighten'
        QtMocHelpers::MethodData<QColor(const QColor &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'darken'
        QtMocHelpers::MethodData<QColor(const QColor &, qreal, qreal)>(15, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QReal, 13 }, { QMetaType::QReal, 16 },
        }}),
        // Method 'darken'
        QtMocHelpers::MethodData<QColor(const QColor &, qreal)>(15, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QReal, 13 },
        }}),
        // Method 'darken'
        QtMocHelpers::MethodData<QColor(const QColor &)>(15, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'shade'
        QtMocHelpers::MethodData<QColor(const QColor &, qreal, qreal)>(17, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QReal, 18 }, { QMetaType::QReal, 19 },
        }}),
        // Method 'shade'
        QtMocHelpers::MethodData<QColor(const QColor &, qreal)>(17, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QReal, 18 },
        }}),
        // Method 'tint'
        QtMocHelpers::MethodData<QColor(const QColor &, const QColor &, qreal)>(20, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 21 }, { 0x80000000 | 3, 4 }, { QMetaType::QReal, 13 },
        }}),
        // Method 'tint'
        QtMocHelpers::MethodData<QColor(const QColor &, const QColor &)>(20, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 3, 21 }, { 0x80000000 | 3, 4 },
        }}),
        // Method 'mix'
        QtMocHelpers::MethodData<QColor(const QColor &, const QColor &, qreal)>(22, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 10 }, { 0x80000000 | 3, 11 }, { QMetaType::QReal, 23 },
        }}),
        // Method 'mix'
        QtMocHelpers::MethodData<QColor(const QColor &, const QColor &)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 3, 10 }, { 0x80000000 | 3, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KColorUtilsSingleton, qt_meta_tag_ZN20KColorUtilsSingletonE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KColorUtilsSingleton::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KColorUtilsSingletonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KColorUtilsSingletonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20KColorUtilsSingletonE_t>.metaTypes,
    nullptr
} };

void KColorUtilsSingleton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<KColorUtilsSingleton *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { qreal _r = _t->hue((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 1: { qreal _r = _t->chroma((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 2: { qreal _r = _t->luma((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 3: { QColor _r = _t->hcyColor((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 4: { QColor _r = _t->hcyColor((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 5: { qreal _r = _t->contrastRatio((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 6: { QColor _r = _t->lighten((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 7: { QColor _r = _t->lighten((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 8: { QColor _r = _t->lighten((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 9: { QColor _r = _t->darken((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 10: { QColor _r = _t->darken((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 11: { QColor _r = _t->darken((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 12: { QColor _r = _t->shade((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 13: { QColor _r = _t->shade((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 14: { QColor _r = _t->tint((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 15: { QColor _r = _t->tint((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 16: { QColor _r = _t->mix((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 17: { QColor _r = _t->mix((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}
QT_WARNING_POP
