/****************************************************************************
** Meta object code from reading C++ file 'systeminhibitor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kguiaddons-6.27.0/src/qml/systeminhibitor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'systeminhibitor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SystemInhibitorE_t {};
} // unnamed namespace

template <> constexpr inline auto SystemInhibitor::qt_create_metaobjectdata<qt_meta_tag_ZN15SystemInhibitorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SystemInhibitor",
        "QML.Element",
        "auto",
        "QML.Extended",
        "KSystemInhibitor",
        "QML.ExtensionIsNamespace",
        "true",
        "windowChanged",
        "",
        "typesChanged",
        "reasonChanged",
        "enabledChanged",
        "window",
        "QWindow*",
        "types",
        "KSystemInhibitor::Types",
        "reason",
        "enabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'windowChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typesChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reasonChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'window'
        QtMocHelpers::PropertyData<QWindow*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'types'
        QtMocHelpers::PropertyData<KSystemInhibitor::Types>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Required, 1),
        // property 'reason'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Required, 2),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<SystemInhibitor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN15SystemInhibitorE[] = {
    QMetaObject::SuperData::link<KSystemInhibitor::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject SystemInhibitor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SystemInhibitorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SystemInhibitorE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN15SystemInhibitorE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SystemInhibitorE_t>.metaTypes,
    nullptr
} };

void SystemInhibitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SystemInhibitor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->windowChanged(); break;
        case 1: _t->typesChanged(); break;
        case 2: _t->reasonChanged(); break;
        case 3: _t->enabledChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SystemInhibitor::*)()>(_a, &SystemInhibitor::windowChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInhibitor::*)()>(_a, &SystemInhibitor::typesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInhibitor::*)()>(_a, &SystemInhibitor::reasonChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SystemInhibitor::*)()>(_a, &SystemInhibitor::enabledChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWindow* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QWindow**>(_v) = _t->m_window; break;
        case 1: *reinterpret_cast<KSystemInhibitor::Types*>(_v) = _t->m_types; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_reason; break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->m_enabled; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_window, *reinterpret_cast<QWindow**>(_v)))
                Q_EMIT _t->windowChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_types, *reinterpret_cast<KSystemInhibitor::Types*>(_v)))
                Q_EMIT _t->typesChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_reason, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->reasonChanged();
            break;
        case 3: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SystemInhibitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SystemInhibitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SystemInhibitorE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int SystemInhibitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void SystemInhibitor::windowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SystemInhibitor::typesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SystemInhibitor::reasonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SystemInhibitor::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
