/****************************************************************************
** Meta object code from reading C++ file 'kkeysequencerecorder.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kguiaddons-6.27.0/src/recorder/kkeysequencerecorder.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kkeysequencerecorder.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20KKeySequenceRecorderE_t {};
} // unnamed namespace

template <> constexpr inline auto KKeySequenceRecorder::qt_create_metaobjectdata<qt_meta_tag_ZN20KKeySequenceRecorderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KKeySequenceRecorder",
        "gotKeySequence",
        "",
        "QKeySequence",
        "keySequence",
        "recordingChanged",
        "windowChanged",
        "currentKeySequenceChanged",
        "multiKeyShortcutsAllowedChanged",
        "modifierlessAllowedChanged",
        "modifierOnlyAllowedChanged",
        "patternsChanged",
        "cancelRecording",
        "startRecording",
        "isRecording",
        "currentKeySequence",
        "window",
        "QWindow*",
        "modifierlessAllowed",
        "multiKeyShortcutsAllowed",
        "modifierOnlyAllowed",
        "patterns",
        "Patterns",
        "Pattern",
        "Modifier",
        "Key",
        "ModifierAndKey"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'gotKeySequence'
        QtMocHelpers::SignalData<void(const QKeySequence &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'recordingChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentKeySequenceChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'multiKeyShortcutsAllowedChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modifierlessAllowedChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modifierOnlyAllowedChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'patternsChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cancelRecording'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'startRecording'
        QtMocHelpers::MethodData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isRecording'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'currentKeySequence'
        QtMocHelpers::PropertyData<QKeySequence>(15, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'window'
        QtMocHelpers::PropertyData<QWindow*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'modifierlessAllowed'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'multiKeyShortcutsAllowed'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'modifierOnlyAllowed'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'patterns'
        QtMocHelpers::PropertyData<Patterns>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'Patterns'
        QtMocHelpers::EnumData<Patterns>(22, 23, QMC::EnumIsFlag).add({
            {   24, Pattern::Modifier },
            {   25, Pattern::Key },
            {   26, Pattern::ModifierAndKey },
        }),
    };
    return QtMocHelpers::metaObjectData<KKeySequenceRecorder, qt_meta_tag_ZN20KKeySequenceRecorderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KKeySequenceRecorder::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KKeySequenceRecorderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KKeySequenceRecorderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20KKeySequenceRecorderE_t>.metaTypes,
    nullptr
} };

void KKeySequenceRecorder::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KKeySequenceRecorder *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->gotKeySequence((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 1: _t->recordingChanged(); break;
        case 2: _t->windowChanged(); break;
        case 3: _t->currentKeySequenceChanged(); break;
        case 4: _t->multiKeyShortcutsAllowedChanged(); break;
        case 5: _t->modifierlessAllowedChanged(); break;
        case 6: _t->modifierOnlyAllowedChanged(); break;
        case 7: _t->patternsChanged(); break;
        case 8: _t->cancelRecording(); break;
        case 9: _t->startRecording(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KKeySequenceRecorder::*)(const QKeySequence & )>(_a, &KKeySequenceRecorder::gotKeySequence, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KKeySequenceRecorder::*)()>(_a, &KKeySequenceRecorder::recordingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KKeySequenceRecorder::*)()>(_a, &KKeySequenceRecorder::windowChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KKeySequenceRecorder::*)()>(_a, &KKeySequenceRecorder::currentKeySequenceChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KKeySequenceRecorder::*)()>(_a, &KKeySequenceRecorder::multiKeyShortcutsAllowedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KKeySequenceRecorder::*)()>(_a, &KKeySequenceRecorder::modifierlessAllowedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KKeySequenceRecorder::*)()>(_a, &KKeySequenceRecorder::modifierOnlyAllowedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KKeySequenceRecorder::*)()>(_a, &KKeySequenceRecorder::patternsChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWindow* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isRecording(); break;
        case 1: *reinterpret_cast<QKeySequence*>(_v) = _t->currentKeySequence(); break;
        case 2: *reinterpret_cast<QWindow**>(_v) = _t->window(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->modifierlessAllowed(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->multiKeyShortcutsAllowed(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->modifierOnlyAllowed(); break;
        case 6: QtMocHelpers::assignFlags<Patterns>(_v, _t->patterns()); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setCurrentKeySequence(*reinterpret_cast<QKeySequence*>(_v)); break;
        case 2: _t->setWindow(*reinterpret_cast<QWindow**>(_v)); break;
        case 3: _t->setModifierlessAllowed(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setMultiKeyShortcutsAllowed(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setModifierOnlyAllowed(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setPatterns(*reinterpret_cast<Patterns*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KKeySequenceRecorder::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KKeySequenceRecorder::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KKeySequenceRecorderE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KKeySequenceRecorder::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KKeySequenceRecorder::gotKeySequence(const QKeySequence & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KKeySequenceRecorder::recordingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KKeySequenceRecorder::windowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KKeySequenceRecorder::currentKeySequenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KKeySequenceRecorder::multiKeyShortcutsAllowedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KKeySequenceRecorder::modifierlessAllowedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KKeySequenceRecorder::modifierOnlyAllowedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KKeySequenceRecorder::patternsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
